tietools.iterate_nontrivial_tie_chains_in_expr
==============================================

.. autofunction:: abjad.tools.tietools.iterate_nontrivial_tie_chains_in_expr.iterate_nontrivial_tie_chains_in_expr
   :noindex:
